@@ -11,20 +11,27 @@ class UserField(ForeignKey):
     """
 
     def __init__(self, **kwargs):
+        kwargs.setdefault('to', User)
         kwargs.setdefault('null', True)
         kwargs.setdefault('blank', True)
-        ForeignKey.__init__(self, User, **kwargs)
+        ForeignKey.__init__(self, **kwargs)
+
 
-      
 class CreatorField(UserField):
     """ CreatorField
 
     By default, sets editable=False, default=threadlocals.get_current_user
     """
 
+    def get_current_user(self):
+        user = threadlocals.get_current_user()
+        if user and not user.is_authenticated():
+            user = None
+        return user
+
     def __init__(self, **kwargs):
         kwargs.setdefault('editable', False)
-        kwargs.setdefault('default', threadlocals.get_current_user)
+        kwargs.setdefault('default', self.get_current_user)
         UserField.__init__(self, **kwargs)
 
 
@@ -40,9 +47,17 @@ class EditorField(CreatorField):
         super(CreatorField, self).__init__(**kwargs)
 
     def pre_save(self, model_instance, add):
-        value = threadlocals.get_current_user()
+        value = self.get_current_user()
         setattr(model_instance, self.name, value)
         if value:
             value = value.pk
         setattr(model_instance, self.attname, value)
         return value
+
+try:
+    from south.modelsinspector import add_introspection_rules
+except ImportError:
+    add_introspection_rules = False
+
+if add_introspection_rules:
+    add_introspection_rules([], [r"^threaded_multihost\.fields\.(User|Creator|Editor)Field"])
